class Bike:

    def __init__(self, data: dict):
        self.id = data["id"]
        self.number = data["number"]
        self.type = data["type"]
        self.status = data["status"]
        self.ratings = data["rating"]
        self.stationNumber = data["stationNumber"]



from .station import Station
from ..velov_api import Api
from typing import List

class Stations:

    def __init__(self):
        self.stations = []

    def get_stations(self):
        stations = [Station(sation) for sation in Api.get_stations()]
        return stations

    def get_station(self, stationNumber: int) -> Station:

        station_data = Api.get_station(stationNumber)
        station = Station(station_data)
        return station




import requests


class VelovApi:


    def __init__(self):
        self.session = requests.Session()
        self.refreshToken = None
        self.accessToken = None

        self.BASE_URL = "https://api.cyclocity.fr/"
        self.START_AUTH_URL = self.BASE_URL + "auth/environments/PRD/client_tokens"
        self.AUTH_DATA = {
            "code": "vls.web.lyon:PRD",
            "key": "c3d9f5c22a9157a7cc7fe0e38269573bdd2f13ec48f867360ecdcbd35b196f87"
        }

    def set_tokens(self):
        response = self.session.post(self.START_AUTH_URL, json=self.AUTH_DATA)
        response = response.json()
        self.refreshToken = response['refreshToken']
        self.accessToken = response["accessToken"]
        self.session.headers.update({"Authorization": f"Taknv1 {self.accessToken}"})

        print("Done getting tokens")

    def get_station(self, stationNumber: int):
        url = f"{self.BASE_URL}contracts/lyon/stations/{stationNumber}"
        response = self.session.get(
            url,
            headers={"Content-Type": "application/vnd.station.v4+json"}
        )
        return response.json()

    def get_stations(self):
        url = f"{self.BASE_URL}contracts/lyon/stations"
        response = self.session.get(
            url,
            headers={"Content-Type": "application/vnd.bikes.v3+json"},
        )
        json = response.json()

        return json

    def get_station_bikes(self, stationNumber: int):
        url = f"https://api.cyclocity.fr/contracts/lyon/bikes?stationNumber={stationNumber}"

        response = self.session.get(
            url,
            headers={"Content-Type": "application/vnd.bikes.v3+json"},
            params={"stationNumber": stationNumber}
        )
        json = response.json()
        return json

    def get_bikes(self):
        url = f"https://api.cyclocity.fr/contracts/lyon/bikes"

        response = self.session.get(
            url,
            headers={"Content-Type": "application/vnd.bikes.v3+json"},
        )
        json = response.json()
        return json


Api = VelovApi()




from .stations.stations import Stations
from .bikes.bikes import Bikes

from .velov_api import Api

class Velov:

    def __init__(self):
        self.stations: Stations = Stations()
        self.bikes: Bikes = Bikes()

    def start(self):
        Api.set_tokens()



from ..velov_api import Api
from typing import List
from .bike import Bike

class Bikes:

    def __inti__(self):
        pass

    def get_bikes(self) -> List[Bike]:
        bikes = Api.get_bikes()
        return [Bike(bike_data) for bike_data in bikes]



from setuptools import setup, find_packages
import setuptools


VERSION = "0.0.2"
DESCRIPTION = "Velo'v API wrapper for python"

with open("README.md", "r", encoding="utf-8") as fh:
    LONG_DESCRIPTION = fh.read()

# Setting up
setup(
    # the name must match the folder name 'verysimplemodule'
    name="pyVelov",
    version=VERSION,
    author="Aimé Risson",
    author_email="aime.risson.1@gmail.fr",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    install_requires=["requests"],
    keywords=["python", "Velo'v api", "Velo'v API wrapper", "python velo'v", "velov", "lyon", "velov lyon"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Intended Audience :: Education",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
    #url="https://github.com/aime-risson/vinted-api-wrapper",
)


class Station:
    """
    Defines a Velo'v staion
    """

    def __init__(self, data: dict) -> None:
        self.id = data["id"]
        self.name = data["name"]
        self.number = data["number"]
        self.open = data["open"]
        self.updatedAt = data["updatedAt"]
        self.number_of_bikes = \
            data["availabilities"]["main"]["bikes"]["electrical"] \
            + data["availabilities"]["main"]["bikes"]["mechanical"]

        self.stands = data["availabilities"]["main"]["stands"]
        self.data = data



